#include <windows.h>
#include "pwm.h"
#include "Coproc.h"

#define BASE_FREQ_VF61 83300000										///< Maximum base freq for PWM in VF61 is 83.3 Mhz(83300000 Hz)
#define BASE_FREQ_VF50_IMX6 66000000								///< maximum base freq for Vf50 and iMX6 is 66 MHz(66000000 Hz)

#define MAX_PWM_VALUE 65536											///< maximum pwm period value
#define PWM_DUTY(pwm_duty_cycle) (MAX_PWM_VALUE*pwm_duty_cycle)/100 ///< map duty cycle value from 1 to 100 to 0 to 65536
#define EXIT 1

int WINAPI WinMain(HINSTANCE instance, HINSTANCE prevInstance, LPWSTR cmdLine, int cmdShow)
{
	eSoc     socType;												///< To get soc type
	tVersion ver;													///< To get library version
	HANDLE	pwmHandle		= NULL;									///< Handle to PWM library
    DWORD	dutyPercent		= 0;									///< PWM duty cycle percentage variable
    BOOL	returnValue		= FALSE;								///< Variable to get return value
	DWORD	pwmMenu			= 0;									///< Variable to get user choice
	DWORD	pwmScale		= 0;									///< Variable to get prescaler value
	DWORD	maxBaseFreq     = BASE_FREQ_VF50_IMX6;					///< maximum base freq for pwm
	CHAR	*optionString    = "\nEnter prescale (1 - 8192):";		///< User message for selecting prescale 
    wprintf(L"******Toradex PWM demo******\n");
	socType = Cop_GetSoc();											///< Get SOC type
	if((socType == Soc_VF61)||(socType == Soc_VF50))	
	{
		maxBaseFreq = BASE_FREQ_VF61;				
		optionString = "\nEnter prescale (1, 2, 4, 8, 16, 32, 64, 128):";
	}
	Pwm_GetVersion(&ver);											///< Get Library version
	wprintf(L"Toradex Library Version %d:%d:%d", ver.Major, ver.Minor, ver.Build);
    pwmHandle = Pwm_Init(L"PWM2");									///< Initialize PWMx, without affecting hardware registers
    if (pwmHandle == NULL)
    {
        wprintf(L"Error in Pwm_Init()\r\n");
    }
    returnValue = Pwm_SetConfigInt(pwmHandle, L"BaseFreq", maxBaseFreq, StoreVolatile); ///< Set PWM Base frequency .
	if(returnValue == FALSE)
	{
		wprintf(L"Error in Pwm_SetConfigInt()\r\n");
	}
    returnValue = Pwm_Open(pwmHandle);								///< Open PWM library
	if(returnValue == FALSE)
	{
		wprintf(L"Error in Pwm_Open()\r\n");
	}
	while (pwmMenu != EXIT)
    {
		printf(optionString);									
        scanf_s("%d", &pwmScale);									///< Get prescale value from user
		fflush(stdin);
        printf("\nDuty (1-100)\t:"); 
        scanf_s("%d", &dutyPercent);								///< Get user choice/ selction
        Pwm_SetPwm(pwmHandle, maxBaseFreq/pwmScale, PWM_DUTY(dutyPercent));///< Assign percentage duty cycle in PWM controller and set frequency 
        printf("\nEnter 1 to Exit\t:"); 
        scanf_s("%d", &pwmMenu);									

     }     
    printf("\nPress enter to exit");
    fflush(stdin);
    getchar();
    if(Pwm_Close(pwmHandle) == FALSE)								///< Close pwm channel											
	{
		printf("\nUnable to Close PWM Library");
		return(FALSE);
	}
	if(Pwm_Deinit(pwmHandle) == FALSE)								///< Deinit pwm channel
	{
		printf("\nUnable to Deinit PWM handle");						
		return(FALSE);
	}											
    return(TRUE);
}
